@@ -22,14 +22,14 @@
  * along with mx-remastercc.  If not, see <http://www.gnu.org/licenses/>.
  **********************************************************************/
 
-
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
 
 #include <QMessageBox>
 #include <QProcess>
 
-namespace Ui {
+namespace Ui
+{
 class MainWindow;
 }
 
@@ -38,7 +38,6 @@ struct Result {
     QString output;
 };
 
-
 class MainWindow : public QDialog
 {
     Q_OBJECT
@@ -47,26 +46,25 @@ public:
     explicit MainWindow(QWidget *parent = nullptr);
     ~MainWindow();
 
-    Result runCmd(QString cmd);
+    Result runCmd(const QString &cmd);
 
     QString version;
     QString output;
 
-    void displayDoc(QString url);
+    static void displayDoc(const QString &url);
+    void setConnections();
     void setup();
 
 private slots:
-    void on_buttonAbout_clicked();
-    void on_buttonHelp_clicked();
-    void on_buttonSetupPersistence_clicked();
-    void on_buttonConfigPersistence_clicked();
-    void on_buttonSaveRootPersist_clicked();
-    void on_buttonRemaster_clicked();
+    void pushAbout_clicked();
+    static void pushHelp_clicked();
+    void pushSetupPersistence_clicked();
+    void pushConfigPersistence_clicked();
+    void pushSaveRootPersist_clicked();
+    void pushRemaster_clicked();
 
 private:
     Ui::MainWindow *ui;
 };
 
-
 #endif // MXSNAPSHOT_H
-
